@@ -117,6 +117,23 @@ root of the repository.
           src: src
           repo-path: cpputest/cpputest
 
+It is also possible to use an ``*`` to match only certain files with the ``src`` tag.
+The following manifest will only checkout files in folder ``src`` with the ``*.h`` extension.
+
+.. code-block:: yaml
+
+    manifest:
+        version: 0.0
+
+        remotes:
+        - name: github
+          url-base: https://github.com/
+
+        projects:
+        - name: cpputest
+          src: src/*.h
+          repo-path: cpputest/cpputest
+
 VCS type
 ########
 *DFetch* does it best to find out what type of version control system (vcs) the remote url is,
@@ -169,7 +186,8 @@ with the ``patch:`` attribute.
           repo-path: cpputest/cpputest
           patch: local_changes.patch
 
-The patch should be *relative* and can be generated as such:
+The patch can be generated using the *Dfetch* :ref:`Diff` command.
+Alternately the patch can be generated manually as such. Note that it should be *relative*.
 
 .. code-block:: sh
 
